# Shipping-Tracking
BP PAribas: 3132

pine stuff
:  https://t.17track.net/en#nums=LT702345621NL
	
3D printer
:	 https://www.geekbuying.com/buyerOrder/orderDetail?id=aBsUCzd9Wc8%3d&state=

https://www.reddit.com/r/SidewinderX1/comments/q0oqyr/sidewinder_x2_prusa_slicer_profile/

PicoPC